==> scribus_0.6.orig.tar.gz: scribus-0.6/scribus/navigator.h <==
/***************************************************************************
                          navigator.h  -  description
                             -------------------
    begin                : Fri Feb 22 2002
    copyright            : (C) 2002 by Franz Schmid
    email                : Franz.Schmid@altmuehlnet.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef NAVIGATOR_H
#define NAVIGATOR_H

#include <qlabel.h>
#include <qpixmap.h>
#include "scribusview.h"

/**
  *@author Franz Schmid
  */

class Navigator : public QLabel  {

Q_OBJECT

public: 
	Navigator(QWidget *parent, int Size, int Seite, ScribusView* vie);
	~Navigator();
	void mouseMoveEvent(QMouseEvent *m);
	void mousePressEvent(QMouseEvent *m);
	void mouseReleaseEvent(QMouseEvent *m);
	void paintEvent(QPaintEvent *e);
	void drawMark(int x, int y);
	void SetSeite(int Seite, int Size);
	int Xp;
	int Yp;
	ScribusView* view;
	QPixmap pmx;
	
signals:
	void Coords(float x, float y);
};

#endif

==> scribus-1.1.3.tar.gz: scribus-1.1.3/scribus/navigator.h <==
/***************************************************************************
                          navigator.h  -  description
                             -------------------
    begin                : Fri Feb 22 2002
    copyright            : (C) 2002 by Franz Schmid
    email                : Franz.Schmid@altmuehlnet.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef NAVIGATOR_H
#define NAVIGATOR_H

#include <qlabel.h>
#include <qpixmap.h>
#include "scribusview.h"

/**
  *@author Franz Schmid
  */

class Navigator : public QLabel  {

Q_OBJECT

public: 
	Navigator(QWidget *parent, int Size, int Seite, ScribusView* vie, QString fn = "");
	~Navigator() {};
	void mouseMoveEvent(QMouseEvent *m);
	void mousePressEvent(QMouseEvent *m);
	void mouseReleaseEvent(QMouseEvent *m);
	void paintEvent(QPaintEvent *e);
	void drawMark(int x, int y);
	bool SetSeite(int Seite, int Size, QString fn = "");
	int Xp;
	int Yp;
	int Breite;
	int Hoehe;
	ScribusView* view;
	QPixmap pmx;
	
signals:
	void Coords(double x, double y);
};

#endif
